.. DRF Magic documentation master file, created by
   sphinx-quickstart on Wed Oct 21 12:05:36 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to DRF Magic's documentation!
=====================================

Django REST Framework Magic (DRF Magic) is a Django application that builds off our all of my
personal best practices of boiler-plates of working with a RESTful Django application. It makes a
fair amount of subjective coding decisions, but I hope that others see the benefit and
ease-of-development that they provide.

Table of Contents
+++++++++++++++++

.. toctree::
   :maxdepth: 2
   :glob:

   areas/*
   dev/contributing

Indices and tables
++++++++++++++++++

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
